@@ -39,12 +39,6 @@
 #include <vector>
 #include <algorithm>
 #include <wx/wupdlock.h>
-#ifdef USE_WEBVIEW
-#include <wx/webview.h>
-#ifdef __WXMSW__
-#include <wx/msw/webview_ie.h>
-#endif
-#endif
 
 #define MC_LINE_SKIP Scale_Px(2)
 #define MC_TEXT_PADDING Scale_Px(1)
@@ -265,7 +259,7 @@ public:
   void SetZoomFactor_temporarily(double newzoom){
     if(m_zoomFactor != newzoom)
       RecalculateForce();
-    m_zoomFactor = newzoom; ;
+    m_zoomFactor = newzoom;
   }
 
   /*! Scales a distance [in pixels] according to the zoom factor
@@ -292,6 +286,12 @@ public:
   // cppcheck-suppress functionConst
   wxString GetSymbolFontName() const;
 
+  //! Returns a list of chars we need to escape in maxima
+  static const wxString CharsNeedingQuotes()
+    {
+      return wxString(wxS("°,\\'\"()[]-{}^+*/&§?:;=#<>$"));
+    }
+
   wxFontWeight IsBold(long st) const;
 
   wxFontStyle IsItalic(long st) const;
