@@ -77,7 +77,7 @@ void EvaluationQueue::AddToQueue(GroupCell *gr) {
     m_workingGroupChanged = true;
   }
   m_size++;
-  m_queue.push_back(gr);
+  m_queue.push_back(CellPtr<GroupCell>(gr));
 }
 
 /**
@@ -159,7 +159,7 @@ wxString EvaluationQueue::GetCommand() {
   if (m_commands.empty())
     return {};
 
-  auto retval = m_commands.front().GetString();
+  const auto &retval = m_commands.front().GetString();
 
   m_userLabel.Clear();
   wxString userLabel;
