@@ -1235,7 +1235,17 @@ std::unique_ptr<Cell> MathParser::ParseTag(wxXmlNode *node, bool all) {
       break;
   }
 
+
+  /* The warning from gcc is correct. But an old MacOs compiler errors out
+     on correct code, here. */
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wredundant-move"
+#endif
   return std::move(tree);
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
 }
 
 std::unique_ptr<Cell> MathParser::ParseLine(wxString s, CellType style) {
