@@ -51,6 +51,7 @@ DiffCell::DiffCell(GroupCell *group, Configuration *config,
          (m_baseCell->ToString() == wxS("\u00B7")))
       m_baseCell->Hide(true);
     }
+  MakeBreakupCells();
 }
 
 DiffCell::DiffCell(GroupCell *group, const DiffCell &cell)
@@ -58,6 +59,7 @@ DiffCell::DiffCell(GroupCell *group, const DiffCell &cell)
              CopyList(group, cell.m_baseCell.get()),
              CopyList(group, cell.m_diffCell.get())) {
   CopyCommonData(cell);
+  MakeBreakupCells();
 }
 
 DEFINE_CELL(DiffCell)
@@ -70,12 +72,12 @@ void DiffCell::MakeBreakupCells() {
   m_close = std::make_unique<TextCell>(m_group, m_configuration, ")");
 }
 
-void DiffCell::Recalculate(AFontSize fontsize) {
+void DiffCell::Recalculate(AFontSize fontsize) const {
   if (NeedsRecalculation(fontsize)) {
     m_baseCell->RecalculateList(fontsize);
     m_diffCell->RecalculateList(fontsize);
     if (!IsBrokenIntoLines()) {
-      m_width = m_baseCell->GetFullWidth() + m_diffCell->GetFullWidth();
+      m_width = m_baseCell->SumOfWidths() + m_diffCell->SumOfWidths();
       m_center = std::max(m_diffCell->GetCenterList(), m_baseCell->GetCenterList());
       m_height =
         m_center + std::max(m_diffCell->GetMaxDrop(), m_baseCell->GetMaxDrop());
@@ -97,7 +99,7 @@ void DiffCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     df.y = point.y;
     m_diffCell->DrawList(df, dc, antialiassingDC);
 
-    bs.x = point.x + m_diffCell->GetFullWidth();
+    bs.x = point.x + m_diffCell->SumOfWidths();
     bs.y = point.y;
     m_baseCell->DrawList(bs, dc, antialiassingDC);
   }
@@ -112,6 +114,10 @@ wxString DiffCell::ToString() const {
     s += tmp->ListToString();
   s += m_diffCell->ListToString();
   s += wxS(")");
+
+  // If we use the 1st derivation we can do without the trailing ",1":
+  if (s.EndsWith(",1)"))
+    s = s.Left(s.Length()-3) + ")";
   return s;
 }
 
@@ -173,11 +179,10 @@ wxString DiffCell::ToXML() const {
     m_baseCell->ListToXML() + wxS("</d>");
 }
 
-bool DiffCell::BreakUp() {
+bool DiffCell::BreakUp() const {
   if (IsBrokenIntoLines())
     return false;
 
-  MakeBreakupCells();
   Cell::BreakUpAndMark();
   m_open->SetNextToDraw(m_baseCell);
   m_baseCell->last()->SetNextToDraw(m_comma);
@@ -188,7 +193,7 @@ bool DiffCell::BreakUp() {
   return true;
 }
 
-void DiffCell::SetNextToDraw(Cell *next) {
+void DiffCell::SetNextToDraw(Cell *next) const {
   if (IsBrokenIntoLines())
     m_close->SetNextToDraw(next);
   else
