@@ -43,6 +43,7 @@ FracCell::FracCell(GroupCell *group, Configuration *config,
   InitBitFields_FracCell();
   SetStyle(TS_VARIABLE);
   SetupBreakUps();
+  MakeDivideCell();
 }
 
 FracCell::FracCell(GroupCell *group, const FracCell &cell)
@@ -53,6 +54,7 @@ FracCell::FracCell(GroupCell *group, const FracCell &cell)
   SetupBreakUps();
   if (cell.m_inExponent)
     SetIsExponent();
+  MakeDivideCell();
 }
 
 DEFINE_CELL(FracCell)
@@ -83,7 +85,7 @@ void FracCell::MakeDivideCell() {
   m_divide = m_divideOwner.get();
 }
 
-void FracCell::Recalculate(AFontSize fontsize) {
+void FracCell::Recalculate(AFontSize fontsize) const {
   if (NeedsRecalculation(fontsize)) {
     if (m_inExponent || IsBrokenIntoLines()) {
       m_displayedNum->RecalculateList(fontsize);
@@ -122,8 +124,8 @@ void FracCell::Recalculate(AFontSize fontsize) {
         else
           m_horizontalGapRight = 0;
 
-        m_width = std::max(m_displayedNum->GetFullWidth(),
-                           m_displayedDenom->GetFullWidth()) +
+        m_width = std::max(m_displayedNum->SumOfWidths(),
+                           m_displayedDenom->SumOfWidths()) +
           2 * m_protrusion + m_horizontalGapLeft + m_horizontalGapRight;
         m_height =
           Num()->GetHeightList() + Denom()->GetHeightList() + Scale_Px(6.5);
@@ -145,9 +147,9 @@ void FracCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     if (m_inExponent) {
       num = point;
       wxPoint divide(point);
-      divide.x += m_displayedNum->GetFullWidth();
+      divide.x += m_displayedNum->SumOfWidths();
       denom = divide;
-      denom.x += m_divide->GetFullWidth();
+      denom.x += m_divide->SumOfWidths();
 
       m_displayedNum->DrawList(num, dc, antialiassingDC);
       m_divide->Draw(divide, dc, antialiassingDC);
@@ -155,7 +157,7 @@ void FracCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     } else {
       num.x = point.x + m_horizontalGapLeft +
         (m_width - m_horizontalGapLeft - m_horizontalGapRight -
-         m_displayedNum->GetFullWidth()) /
+         m_displayedNum->SumOfWidths()) /
         2;
       num.y = point.y - m_displayedNum->GetHeightList() +
         m_displayedNum->GetCenterList();
@@ -163,7 +165,7 @@ void FracCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
 
       denom.x = point.x + m_horizontalGapLeft +
         (m_width - m_horizontalGapLeft - m_horizontalGapRight -
-         m_displayedDenom->GetFullWidth()) /
+         m_displayedDenom->SumOfWidths()) /
         2;
       denom.y = point.y + m_displayedDenom->GetCenterList() + Scale_Px(4);
       m_displayedDenom->DrawList(denom, dc, antialiassingDC);
@@ -296,7 +298,7 @@ void FracCell::SetIsExponent() {
   }
 }
 
-void FracCell::SetupBreakUps() {
+void FracCell::SetupBreakUps() const {
   m_displayedNum = m_numParenthesis.get();
   m_displayedDenom = m_denomParenthesis.get();
   if (m_fracStyle == FC_CHOOSE) {
@@ -310,11 +312,10 @@ void FracCell::SetupBreakUps() {
   }
 }
 
-bool FracCell::BreakUp() {
+bool FracCell::BreakUp() const {
   if (m_fracStyle == FC_DIFF || IsBrokenIntoLines())
     return false;
 
-  MakeDivideCell();
   Cell::BreakUpAndMark();
   if (Num() && Num()->GetNext())
     m_displayedNum = m_numParenthesis.get();
@@ -328,7 +329,7 @@ bool FracCell::BreakUp() {
   return true;
 }
 
-void FracCell::SetNextToDraw(Cell *next) {
+void FracCell::SetNextToDraw(Cell *next) const {
   if (IsBrokenIntoLines())
     m_displayedDenom->SetNextToDraw(next);
   else
