@@ -53,7 +53,7 @@ FunCell::FunCell(GroupCell *group, const FunCell &cell)
 
 DEFINE_CELL(FunCell)
 
-void FunCell::Recalculate(AFontSize fontsize) {
+void FunCell::Recalculate(AFontSize fontsize) const {
   if (NeedsRecalculation(fontsize)) {
     m_argCell->RecalculateList(fontsize);
     m_nameCell->RecalculateList(fontsize);
@@ -62,7 +62,7 @@ void FunCell::Recalculate(AFontSize fontsize) {
       m_width = m_center = m_height = 0;
     } else {
       m_width =
-        m_nameCell->GetFullWidth() + m_argCell->GetFullWidth() - Scale_Px(1);
+        m_nameCell->SumOfWidths() + m_argCell->SumOfWidths() - Scale_Px(1);
       m_center = std::max(m_nameCell->GetCenterList(), m_argCell->GetCenterList());
       m_height =
         m_center + std::max(m_nameCell->GetMaxDrop(), m_argCell->GetMaxDrop());
@@ -77,7 +77,7 @@ void FunCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     wxPoint name(point), arg(point);
     m_nameCell->DrawList(name, dc, antialiassingDC);
 
-    arg.x += m_nameCell->GetFullWidth();
+    arg.x += m_nameCell->SumOfWidths();
     m_argCell->DrawList(arg, dc, antialiassingDC);
   }
 }
@@ -153,7 +153,7 @@ wxString FunCell::ToOMML() const {
   return m_nameCell->ListToOMML() + m_argCell->ListToOMML();
 }
 
-bool FunCell::BreakUp() {
+bool FunCell::BreakUp() const {
   if (IsBrokenIntoLines())
     return false;
 
@@ -164,7 +164,7 @@ bool FunCell::BreakUp() {
   return true;
 }
 
-void FunCell::SetNextToDraw(Cell *next) {
+void FunCell::SetNextToDraw(Cell *next) const {
   if (IsBrokenIntoLines())
     m_argCell->last()->SetNextToDraw(next);
   else
