@@ -52,6 +52,7 @@ IntCell::IntCell(GroupCell *group, Configuration *config,
     m_lowerLimit(std::move(lowerLimit)), m_upperLimit(std::move(upperLimit)) {
   InitBitFields_IntCell();
   SetStyle(TS_VARIABLE);
+  MakeBreakUpCells();
 }
 
 IntCell::IntCell(GroupCell *group, Configuration *config,
@@ -81,7 +82,7 @@ void IntCell::MakeBreakUpCells() {
   m_comma3 = std::make_unique<TextCell>(m_group, m_configuration, ",");
 }
 
-void IntCell::Recalculate(AFontSize fontsize) {
+void IntCell::Recalculate(AFontSize fontsize) const {
   if (NeedsRecalculation(fontsize)) {
     wxASSERT(fontsize.IsValid());
 
@@ -114,9 +115,9 @@ void IntCell::Recalculate(AFontSize fontsize) {
       // The sign width in this case is defined by the sign height and the sign's aspect
       // ratio
       m_signWidth = m_signHeight * 19.879 / 51.781;
-      m_width = m_signWidth + m_base->GetFullWidth() +
-        std::max(m_upperLimit->GetFullWidth(), m_lowerLimit->GetFullWidth()) +
-        m_var->GetFullWidth() + Scale_Px(4);
+      m_width = m_signWidth + m_base->SumOfWidths() +
+        std::max(m_upperLimit->SumOfWidths(), m_lowerLimit->SumOfWidths()) +
+        m_var->SumOfWidths() + Scale_Px(4);
       if (HasLimits()) {
 
         m_center = std::max(std::max(m_signHeight / 2,
@@ -141,7 +142,7 @@ void IntCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
   if (DrawThisCell(point)) {
     wxPoint base(point), lowerLimit(point), upperLimit(point), var(point), sign(point);
     base.x += m_signWidth;
-    base.x += std::max(m_upperLimit->GetFullWidth(), m_lowerLimit->GetFullWidth());
+    base.x += std::max(m_upperLimit->SumOfWidths(), m_lowerLimit->SumOfWidths());
 
     SetPen(antialiassingDC, 1.5);
 
@@ -161,12 +162,12 @@ void IntCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
       m_upperLimit->DrawList(upperLimit, dc, antialiassingDC);
       m_lowerLimit->DrawList(lowerLimit, dc, antialiassingDC);
       
-      base.x += std::max(m_upperLimit->GetFullWidth(), m_lowerLimit->GetFullWidth());
+      base.x += std::max(m_upperLimit->SumOfWidths(), m_lowerLimit->SumOfWidths());
     }
 
     m_base->DrawList(base, dc, antialiassingDC);
 
-    var.x = base.x + m_base->GetFullWidth();
+    var.x = base.x + m_base->SumOfWidths();
     m_var->DrawList(var, dc, antialiassingDC);
   }
 }
@@ -326,11 +327,10 @@ wxString IntCell::ToXML() const {
       wxS("</in>");
 }
 
-bool IntCell::BreakUp() {
+bool IntCell::BreakUp() const {
   if (IsBrokenIntoLines())
     return false;
 
-  MakeBreakUpCells();
   Cell::BreakUpAndMark();
   m_close->SetNextToDraw(m_nextToDraw);
   m_nextToDraw = m_open;
@@ -353,7 +353,7 @@ bool IntCell::BreakUp() {
   return true;
 }
 
-void IntCell::SetNextToDraw(Cell *next) {
+void IntCell::SetNextToDraw(Cell *next) const {
   if (IsBrokenIntoLines())
     m_close->SetNextToDraw(next);
   else
