@@ -38,30 +38,30 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  void Recalculate(AFontSize fontsize) override;
+  void Recalculate(const AFontSize fontsize) const override;
   void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
-  bool BreakUp() override;
-  void SetNextToDraw(Cell *next) override;
+  bool BreakUp() const override;
+  void SetNextToDraw(Cell *next) const override;
   size_t GetInnerCellCount() const override { if(m_innerCell) return 1; else return 0; }
   // cppcheck-suppress objectIndex
   Cell *GetInnerCell(size_t index) const override;
 
 protected:
-  virtual void UpdateDisplayedText() override;
+  virtual void UpdateDisplayedText() const override;
 private:
   //** Large objects (144 bytes)
   //**
   //! The first few digits
-  wxString m_numStart;
+  mutable wxString m_numStart;
   //! The inividual digits, if this cell is broken into lines
-  std::unique_ptr<Cell> m_innerCell;
+  mutable std::unique_ptr<Cell> m_innerCell;
   //! The "not all digits displayed" message.
-  wxString m_ellipsis;
+  mutable wxString m_ellipsis;
 
   //** 4-byte objects (12 bytes)
   //**
-  int m_numStartWidth = 0;
-  int m_ellipsisWidth = 0;
+  mutable int m_numStartWidth = 0;
+  mutable int m_ellipsisWidth = 0;
 
   //** Bitfield objects (0 bytes)
   //**
