@@ -25,8 +25,8 @@
 #include <wx/persist/toplevel.h>
 
 Gen5Wiz::Gen5Wiz(wxString lab1, wxString lab2, wxString lab3, wxString lab4,
-                 wxString lab5, wxString val1, wxString val2, wxString val3,
-                 wxString val4, wxString val5, Configuration *cfg,
+                 wxString lab5, const wxString &val1, const wxString &val2, const wxString &val3,
+                 const wxString &val4, const wxString &val5, Configuration *cfg,
                  wxWindow *parent, int id, const wxString &title, bool eq,
                  const wxString &warning, const wxString &warningToolTip,
                  const wxPoint &pos, const wxSize &size, long style)
